@@ -460,7 +460,7 @@ sub create_appender_instance {
             Log::Log4perl::Level::PRIORITY{$system_wide_threshold});
     }
 
-    if($data->{appender}->{$appname}->{threshold}) {
+    if(exists $data->{appender}->{$appname}->{threshold}) {
             die "threshold keyword needs to be uppercase";
     }
 
@@ -553,6 +553,7 @@ sub config_read {
     die "Configuration not defined" unless defined $config;
 
     my @text;
+    my $parser;
 
     $CONFIG_FILE_READS++;  # Count for statistical purposes
 
@@ -643,13 +644,15 @@ sub config_read {
         require Log::Log4perl::Config::DOMConfigurator;
 
         XML::DOM->VERSION($Log::Log4perl::DOM_VERSION_REQUIRED);
-        my $parser = Log::Log4perl::Config::DOMConfigurator->new();
+        $parser = Log::Log4perl::Config::DOMConfigurator->new();
         $data = $parser->parse(\@text);
     } else {
-        my $parser = Log::Log4perl::Config::PropertyConfigurator->new();
+        $parser = Log::Log4perl::Config::PropertyConfigurator->new();
         $data = $parser->parse(\@text);
     }
 
+    $data = $parser->parse_post_process( $data, leaf_paths($data) );
+
     return $data;
 }
 
@@ -714,6 +717,20 @@ sub leaf_paths {
     return \@result;
 }
 
+###########################################
+sub leaf_path_to_hash {
+###########################################
+    my($leaf_path, $data) = @_;
+
+    my $ref = \$data;
+
+    for my $part ( @$leaf_path[0..$#$leaf_path-1] ) {
+        $ref = \$$ref->{ $part };
+    }
+
+    return $ref;
+}
+
 ###########################################
 sub eval_if_perl {
 ###########################################
@@ -1102,10 +1119,6 @@ certainly override it:
 C<write> is the C<mode> that has C<Log::Log4perl::Appender::File>
 explicitely clobber the log file if it exists.
 
-=head1 AUTHOR
-
-Mike Schilli, E<lt>log4perl@perlmeister.comE<gt>
-
 =head1 SEE ALSO
 
 Log::Log4perl::Config::PropertyConfigurator
@@ -1114,4 +1127,12 @@ Log::Log4perl::Config::DOMConfigurator
 
 Log::Log4perl::Config::LDAPConfigurator (coming soon!)
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
+
 =cut
