@@ -59,17 +59,18 @@ Possible config properties for Log::Dispatch::Syslog are
     facility 
     socket   (defaults to 'inet')
 
-=head1 AUTHORS
-
-    Kevin Goess, <cpan@goess.org> 
-    Mike Schilli, <m@perlmeister.com>
-    
-    December, 2002
-
 =head1 SEE ALSO
 
 http://jakarta.apache.org/log4j/docs/
 
 Log::Log4perl::Javamap
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
+
 =cut
